@@ -3,7 +3,7 @@
 # Draw links between points or intervals
 #
 # == param
-# -sector.index1 Index for sector one
+# -sector.index1 Index for the first sector
 # -point1        A single value or a numeric vector of length 2. If it is a 2-elements vector, then
 #                the link would be a belt/ribbon.
 # -sector.index2 Index for the other sector
@@ -54,7 +54,7 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
 	point1 = sort(point1)
 	point2 = sort(point2)
 
-    if(length(point1) == 1 && length(point2) == 1) {
+    if(length(point1) == 1 && length(point2) == 1) {  # single line
         theta1 = circlize(point1, 0, sector.index = sector.index1, track.index = 0)[1, "theta"]
         theta2 = circlize(point2, 0, sector.index = sector.index2, track.index = 0)[1, "theta"]
         
@@ -64,13 +64,19 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
 	        if(directional == 1) {  # point1 to point2
 	        	nr = nrow(d)
 	        	alpha = line_degree(d[nr-1, 1], d[nr-1, 2], d[nr, 1], d[nr, 2])
+	        	oljoin = par("ljoin")
+	        	par(ljoin = "mitre")
 	        	Arrowhead(d[nr, 1], d[nr, 2], alpha, arr.length = arr.length, arr.width = arr.width, 
 	        		arr.adj = 1, arr.type = arr.type, arr.col = col, lcol = col)
+	        	par(ljoin = oljoin)
 	        } else if(directional == -1) {  # point2 to point2
 	        	nr = nrow(d)
 	        	alpha = line_degree(d[2, 1], d[2, 2], d[1, 1], d[1,2])
+	        	oljoin = par("ljoin")
+	        	par(ljoin = "mitre")
 	        	Arrowhead(d[1, 1], d[1, 2], alpha, arr.length = arr.length, arr.width = arr.width, 
 	        		arr.adj = 1, arr.type = arr.type, arr.col = col, lcol = col)
+	        	par(ljoin = oljoin)
 	        }
 	    }
     } else if(length(point1) == 1) {
@@ -80,8 +86,8 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
 
         if(degreeDiff2(theta1, theta21) <= degreeDiff(theta22, theta21) &
            degreeDiff2(theta22, theta1) <= degreeDiff(theta22, theta21)) {
-			d = getQuadraticPoints(theta21, theta22, rou1, rou2, h = h, w = w)
-			r = arc.points(theta21, theta22, rou)
+			d = getQuadraticPoints(theta22, theta21, max(rou1,rou2), max(rou1,rou2), h = h, w = w)
+			r = arc.points(theta22, theta21, rou)
 			d = rbind(d, revMat(r))
 			polygon(d, col = col, lty = lty, lwd = lwd, border = border)
 		} else {
@@ -98,17 +104,18 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
 		        d2x = getQuadraticPoints(theta1, theta22, rou1, rou2 - arr.length, h = h, w = w)
 	        	dcenter = getQuadraticPoints(theta1, (theta21 + theta22)/2, rou1, rou2, h = (h+h2)/2, w = (w+w2)/2)
 		    }
-		   	r2 = arc.points(theta21, theta22, rou2)
+		   	r2 = arc.points(theta22, theta21, rou2)
 			if(arr.type == "big.arrow" && directional == 1) {
-				if(nrow(r2) %% 2 == 1) {
-					r2 = r2[ceiling(nrow(r2)/2), , drop = FALSE]
-				} else {
-					r2 = colMeans(r2[c(nrow(r2)/2, nrow(r2)/2+1), , drop = FALSE])
-				}
-				d = rbind(d1x, r2)
+				# if(nrow(r2) %% 2 == 1) {
+				# 	r2 = r2[ceiling(nrow(r2)/2), , drop = FALSE]
+				# } else {
+				# 	r2 = colMeans(r2[c(nrow(r2)/2, nrow(r2)/2+1), , drop = FALSE])
+				# }
+				r2 = arc.midpoint(theta22, theta21, rou2)
+				d = rbind(d1x, revMat(r2))
 				d = rbind(d, revMat(d2x))
 			} else {
-				d = rbind(d1, r2)
+				d = rbind(d1, revMat(r2))
 				d = rbind(d, revMat(d2))
 			}
 			
@@ -118,14 +125,20 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
 		        	lines(dcenter, col = arr.col, lwd = arr.lwd, lty = arr.lty)
 		        	nr = nrow(dcenter)
 		        	alpha = line_degree(dcenter[nr-1, 1], dcenter[nr-1, 2], dcenter[nr, 1], dcenter[nr, 2])
+		        	oljoin = par("ljoin")
+	        		par(ljoin = "mitre")
 		        	Arrowhead(dcenter[nr, 1], dcenter[nr, 2], alpha, arr.length = arr.length, arr.width = arr.width, 
 		        		arr.adj = 1, arr.type = arr.type, arr.col = arr.col, lcol = arr.col)
+		        	par(ljoin = oljoin)
 		        } else if(directional == -1) {  # point2 to point1
 		        	lines(dcenter, col = arr.col, lwd = arr.lwd, lty = arr.lty)
 		        	nr = nrow(dcenter)
 		        	alpha = line_degree(dcenter[2, 1], dcenter[2, 2], dcenter[1, 1], dcenter[1,2])
+		        	oljoin = par("ljoin")
+		        	par(ljoin = "mitre")
 		        	Arrowhead(dcenter[1, 1], dcenter[1, 2], alpha, arr.length = arr.length, arr.width = arr.width, 
 		        		arr.adj = 1, arr.type = arr.type, arr.col = arr.col, lcol = arr.col)
+		        	par(ljoin = oljoin)
 		        }
 		    }
 		}
@@ -137,8 +150,8 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
         
         if(degreeDiff2(theta2, theta11) <= degreeDiff2(theta12, theta11) &
            degreeDiff2(theta12, theta2) <= degreeDiff2(theta12, theta11)) {
-			d = getQuadraticPoints(theta11, theta12, rou1, rou2, h = h, w = w)
-			r = arc.points(theta11, theta12, rou)
+			d = getQuadraticPoints(theta12, theta11, max(rou1,rou2), max(rou1,rou2), h = h, w = w)
+			r = arc.points(theta12, theta11, rou)
 			d = rbind(d, revMat(r))
 			polygon(d, col = col, lty = lty, lwd = lwd, border = border)
 		} else {
@@ -155,17 +168,18 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
 		        d2x = getQuadraticPoints(theta12, theta2, rou1 - arr.length, rou2, h = h, w = w)
 	        	dcenter = getQuadraticPoints((theta11 + theta12)/2, theta2, rou1, rou2, h = (h+h2)/2, w = (w+w2)/2)
 		    }
-			r1 = arc.points(theta11, theta12, rou1)
+			r1 = arc.points(theta12, theta11, rou1)
 			if(arr.type == "big.arrow" && directional == -1) {
-				if(nrow(r1) %% 2 == 1) {
-					r1 = r1[ceiling(nrow(r1)/2), , drop = FALSE]
-				} else {
-					r1 = colMeans(r1[c(nrow(r1)/2, nrow(r1)/2+1), , drop = FALSE])
-				}
-				d = rbind(revMat(d1x), r1)
+				# if(nrow(r1) %% 2 == 1) {
+				# 	r1 = r1[ceiling(nrow(r1)/2), , drop = FALSE]
+				# } else {
+				# 	r1 = colMeans(r1[c(nrow(r1)/2, nrow(r1)/2+1), , drop = FALSE])
+				# }
+				r1 = arc.midpoint(theta12, theta11, rou1)
+				d = rbind(revMat(d1x), revMat(r1))
 				d = rbind(d, d2x)
 			} else {
-				d = rbind(revMat(d1), r1)
+				d = rbind(revMat(d1), revMat(r1))
 				d = rbind(d, d2)
 			}
 			polygon(d, col = col, lty = lty, lwd = lwd, border = border)
@@ -174,14 +188,20 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
 		        	lines(dcenter, col = arr.col, lwd = arr.lwd, lty = arr.lty)
 		        	nr = nrow(dcenter)
 		        	alpha = line_degree(dcenter[nr-1, 1], dcenter[nr-1, 2], dcenter[nr, 1], dcenter[nr, 2])
-		        	Arrowhead(dcenter[nr, 1], dcenter[nr, 2], alpha, arr.length = arr.length, arr.width = arr.width, 
+		        	oljoin = par("ljoin")
+	        		par(ljoin = "mitre")
+	        		Arrowhead(dcenter[nr, 1], dcenter[nr, 2], alpha, arr.length = arr.length, arr.width = arr.width, 
 		        		arr.adj = 1, arr.type = arr.type, arr.col = arr.col, lcol = arr.col)
+	        		par(ljoin = oljoin)
 		        } else if(directional == -1) {  # point2 to point2
 		        	lines(dcenter, col = arr.col, lwd = arr.lwd, lty = arr.lty)
 		        	nr = nrow(dcenter)
 		        	alpha = line_degree(dcenter[2, 1], dcenter[2, 2], dcenter[1, 1], dcenter[1,2])
+		        	oljoin = par("ljoin")
+		        	par(ljoin = "mitre")
 		        	Arrowhead(dcenter[1, 1], dcenter[1, 2], alpha, arr.length = arr.length, arr.width = arr.width, 
 		        		arr.adj = 1, arr.type = arr.type, arr.col = arr.col, lcol = arr.col)
+		        	par(ljoin = oljoin)
 		        }
 		    }
 		}
@@ -195,14 +215,14 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
 
 		if(degreeDiff2(theta12, theta21) <= degreeDiff2(theta22, theta21) + degreeDiff2(theta12, theta11) &
 		   degreeDiff2(theta12, theta21) >= degreeDiff2(theta22, theta11)) {
-			d = getQuadraticPoints(theta12, theta21, rou1, rou2, h = h, w = w)
+			d = getQuadraticPoints(theta12, theta21, max(rou1,rou2), max(rou1,rou2), h = h, w = w)
 			r = arc.points(theta12, theta21, rou)
 			d = rbind(d, revMat(r))
 			polygon(d, col = col, lty = lty, lwd = lwd, border = border)
 		} else if(degreeDiff2(theta22, theta11) <= degreeDiff2(theta12, theta11) + degreeDiff2(theta22, theta21) &
 			      degreeDiff2(theta22, theta11) >= degreeDiff2(theta12, theta21)) {
-			d = getQuadraticPoints(theta11, theta22, rou1, rou2, h = h, w = w)
-			r = arc.points(theta11, theta22, rou)
+			d = getQuadraticPoints(theta22, theta11, max(rou1,rou2), max(rou1,rou2), h = h, w = w)
+			r = arc.points(theta22, theta11, rou)
 			d = rbind(d, revMat(r))
 			polygon(d, col = col, lty = lty, lwd = lwd, border = border)
 		} else {
@@ -230,33 +250,35 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
 			    }
 	        	dcenter = getQuadraticPoints((theta11 + theta12)/2, (theta21 + theta22)/2, rou1, rou2, h = (h+h2)/2, w = (w+w2)/2)
 		    }
-			r2 = arc.points(theta21, theta22, rou2)
-			r1 = arc.points(theta11, theta12, rou1)
+			r2 = arc.points(theta22, theta21, rou2)
+			r1 = arc.points(theta12, theta11, rou1)
 
 			if(arr.type == "big.arrow") {
 				if(directional == 1) {
-					if(nrow(r2) %% 2 == 1) {
-						r2 = r2[ceiling(nrow(r2)/2), , drop = FALSE]
-					} else {
-						r2 = colMeans(r2[c(nrow(r2)/2, nrow(r2)/2+1), , drop = FALSE])
-					}
+					# if(nrow(r2) %% 2 == 1) {
+					# 	r2 = r2[ceiling(nrow(r2)/2), , drop = FALSE]
+					# } else {
+					# 	r2 = colMeans(r2[c(nrow(r2)/2, nrow(r2)/2+1), , drop = FALSE])
+					# }
+					r2 = arc.midpoint(theta22, theta21, rou2)
 					d = rbind(d1x, r2)
 			        d = rbind(d, revMat(d2x))
-			        d = rbind(d, revMat(r1))
+			        d = rbind(d, r1)
 			    } else if(directional == -1) {
-			    	if(nrow(r1) %% 2 == 1) {
-						r1 = r1[ceiling(nrow(r1)/2), , drop = FALSE]
-					} else {
-						r1 = colMeans(r1[c(nrow(r1)/2, nrow(r1)/2+1), , drop = FALSE])
-					}
-			    	d = rbind(d1x, revMat(r2))
+			  #   	if(nrow(r1) %% 2 == 1) {
+					# 	r1 = r1[ceiling(nrow(r1)/2), , drop = FALSE]
+					# } else {
+					# 	r1 = colMeans(r1[c(nrow(r1)/2, nrow(r1)/2+1), , drop = FALSE])
+					# }
+					r1 = arc.midpoint(theta12, theta11, rou1)
+			    	d = rbind(d1x, r2)
 			        d = rbind(d, revMat(d2x))
 			        d = rbind(d, r1)
 			    } 
 			} else {
-		        d = rbind(d1, revMat(r2))
+		        d = rbind(d1, r2)
 		        d = rbind(d, revMat(d2))
-		        d = rbind(d, revMat(r1))
+		        d = rbind(d, r1)
 		    }
 			polygon(d, col = col, lty = lty, lwd = lwd, border = border)
 			if(nrow(dcenter) > 1 && arr.type != "big.arrow") {
@@ -264,14 +286,20 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
 		        	lines(dcenter, col = arr.col, lwd = arr.lwd, lty = arr.lty)
 		        	nr = nrow(dcenter)
 		        	alpha = line_degree(dcenter[nr-1, 1], dcenter[nr-1, 2], dcenter[nr, 1], dcenter[nr, 2])
+		        	oljoin = par("ljoin")
+	        		par(ljoin = "mitre")
 		        	Arrowhead(dcenter[nr, 1], dcenter[nr, 2], alpha, arr.length = arr.length, arr.width = arr.width, 
 		        		arr.adj = 1, arr.type = arr.type, arr.col = arr.col, lcol = arr.col)
+		        	par(ljoin = oljoin)
 		        } else if(directional == -1) {  # point2 to point2
 		        	lines(dcenter, col = arr.col, lwd = arr.lwd, lty = arr.lty)
 		        	nr = nrow(dcenter)
 		        	alpha = line_degree(dcenter[2, 1], dcenter[2, 2], dcenter[1, 1], dcenter[1,2])
+		        	oljoin = par("ljoin")
+		        	par(ljoin = "mitre")
 		        	Arrowhead(dcenter[1, 1], dcenter[1, 2], alpha, arr.length = arr.length, arr.width = arr.width, 
 		        		arr.adj = 1, arr.type = arr.type, arr.col = arr.col, lcol = arr.col)
+		        	par(ljoin = oljoin)
 		        }
 		    }
 		}
@@ -280,28 +308,31 @@ circos.link = function(sector.index1, point1, sector.index2, point2,
     return(invisible(NULL))
 }
 
-# points from theta1 to theta2
+# points from theta1 to theta2, reverse clockwise
 arc.points = function(theta1, theta2, rou) {
 	theta1 = theta1 %% 360
 	theta2 = theta2 %% 360
-	theta_diff = (theta1 - theta2) %% 360
+	theta_diff = (theta2 - theta1) %% 360
 	l = as.radian(theta_diff)*rou
 	ncut = l/ (2*pi/circos.par("unit.circle.segments"))
 	ncut = floor(ncut)
 	ncut = ifelse(ncut < 2, 2, ncut)
     
-	x = numeric(ncut)
-	y = numeric(ncut)
-	for(i in seq_len(ncut)) {
-		t = (theta1 - (i-1)*theta_diff/(ncut-1)) %% 360
-		x[i] = rou * cos(as.radian(t))
-		y[i] = rou * sin(as.radian(t))
-	}
+	x = rou * cos(as.radian(theta1 + seq_len(ncut-1)*theta_diff/(ncut-1)))
+	y = rou * sin(as.radian(theta1 + seq_len(ncut-1)*theta_diff/(ncut-1)))
 	d = cbind(x, y)
 	#linesWithArrows(d)
 	return(d)
 }
 
+arc.midpoint = function(theta1, theta2, rou) {
+	theta1 = theta1 %% 360
+	theta2 = theta2 %% 360
+	if(theta2 < theta1) theta2 = theta2 + 360
+	theta = (theta1 + theta2)/2
+	rbind(c(rou*cos(as.radian(theta)), rou*sin(as.radian(theta))))
+}
+
 # points from theta1 to theta2
 # first calcualte bezier curve of which two end points are located at (-d, 0), (d, 0)
 # and the summit is located at (0, 2h)
@@ -393,15 +424,30 @@ getQuadraticPoints = function(theta1, theta2, rou1, rou2, h = NULL, w = 1) {
 
 # 'Rational bezier curve', from wikipedia
 # w: w1
-quadratic.bezier = function(p0, p1, p2, n = 100, w = 1) {
-	
-	t = seq(0, 1, length.out = n)
+# if I know how to calculate the length of bezier curve, then I can choose a betten n
+quadratic.bezier = function(p0, p1, p2, w = 1) {
+
+	ncut = quadratic.bezier.length(p0, p1, p2, w = w)/ (2*pi/circos.par("unit.circle.segments"))
+	ncut = floor(ncut)
+	ncut = ifelse(ncut < 3, 3, ncut)
+	if(ncut %% 2 == 0) ncut = ncut + 1  # odd number
+
+	t = seq(0, 1, length.out = ncut)
 	x = ((1-t)^2 * p0[1] + 2*t*(1-t)*p1[1]*w + t^2*p2[1]) / ((1-t)^2 + 2*t*(1-t)*w + t^2)
 	y = ((1-t)^2 * p0[2] + 2*t*(1-t)*p1[2]*w + t^2*p2[2]) / ((1-t)^2 + 2*t*(1-t)*w + t^2)
 	return(cbind(x, y))
 
 }
 
+quadratic.bezier.length = function(p0, p1, p2, w = 1) {
+	n = 50
+	t = seq(0, 1, length.out = n)
+	x = ((1-t)^2 * p0[1] + 2*t*(1-t)*p1[1]*w + t^2*p2[1]) / ((1-t)^2 + 2*t*(1-t)*w + t^2)
+	y = ((1-t)^2 * p0[2] + 2*t*(1-t)*p1[2]*w + t^2*p2[2]) / ((1-t)^2 + 2*t*(1-t)*w + t^2)
+	sum(sqrt((x[2:n] - x[1:(n-1)])^2 + (y[2:n] - y[1:(n-1)])^2))
+
+}
+
 are.lines.intersected = function(x1, y1, x2, y2) {
 	n1 = length(x1)
 	n2 = length(x2)
@@ -474,6 +520,8 @@ degreeDiff = function (theta1, theta2) {
 
 # used to calculate whether two arcs overlap
 # theta1 is reverse-clockwise of theta2
+# e.g. degreeDiff2(90, 180) = 90
+#  degreeDiff2(180, 90) = 270
 degreeDiff2 = function(theta1, theta2) {
 	(theta2 - theta1) %% 360
 }
